@@ -30,7 +30,7 @@ class TestPad:
 @pytest.fixture(name="cr")
 def _cr():
     return dev.ConsoleRenderer(
-        colors=dev._use_colors, exception_formatter=dev.plain_traceback
+        colors=dev._has_colors, exception_formatter=dev.plain_traceback
     )
 
 
@@ -135,11 +135,11 @@ class TestConsoleRenderer:
         Stdlib levels are rendered aligned, in brackets, and color coded.
         """
         my_styles = dev.ConsoleRenderer.get_default_level_styles(
-            colors=dev._use_colors
+            colors=dev._has_colors
         )
         my_styles["MY_OH_MY"] = my_styles["critical"]
         cr = dev.ConsoleRenderer(
-            colors=dev._use_colors, level_styles=my_styles
+            colors=dev._has_colors, level_styles=my_styles
         )
 
         # this would blow up if the level_styles override failed
@@ -283,11 +283,58 @@ class TestConsoleRenderer:
 
         assert (padded + "\n" + stack) == rv
 
+    def test_exc_info_tuple(self, cr, padded):
+        """
+        If exc_info is a tuple, it is used.
+        """
+
+        try:
+            0 / 0
+        except ZeroDivisionError:
+            ei = sys.exc_info()
+
+        rv = cr(None, None, {"event": "test", "exc_info": ei})
+
+        exc = dev._format_exception(ei)
+
+        assert (padded + "\n" + exc) == rv
+
+    def test_exc_info_bool(self, cr, padded):
+        """
+        If exc_info is True, it is obtained using sys.exc_info().
+        """
+
+        try:
+            0 / 0
+        except ZeroDivisionError:
+            ei = sys.exc_info()
+            rv = cr(None, None, {"event": "test", "exc_info": True})
+
+        exc = dev._format_exception(ei)
+
+        assert (padded + "\n" + exc) == rv
+
+    def test_exc_info_exception(self, cr, padded):
+        """
+        If exc_info is an exception, it is used by converting to a tuple.
+        """
+
+        try:
+            0 / 0
+        except ZeroDivisionError as e:
+            ei = e
+
+        rv = cr(None, None, {"event": "test", "exc_info": ei})
+
+        exc = dev._format_exception((ei.__class__, ei, ei.__traceback__))
+
+        assert (padded + "\n" + exc) == rv
+
     def test_pad_event_param(self, styles):
         """
         `pad_event` parameter works.
         """
-        rv = dev.ConsoleRenderer(42, dev._use_colors)(
+        rv = dev.ConsoleRenderer(42, dev._has_colors)(
             None, None, {"event": "test", "foo": "bar"}
         )
 
@@ -305,7 +352,7 @@ class TestConsoleRenderer:
             + styles.reset
         ) == rv
 
-    @pytest.mark.parametrize("explicit_ei", [True, False])
+    @pytest.mark.parametrize("explicit_ei", ["tuple", "exception", False])
     def test_everything(self, cr, styles, padded, explicit_ei):
         """
         Put all cases together.
@@ -313,8 +360,13 @@ class TestConsoleRenderer:
         if explicit_ei:
             try:
                 0 / 0
-            except ZeroDivisionError:
-                ei = sys.exc_info()
+            except ZeroDivisionError as e:
+                if explicit_ei == "tuple":
+                    ei = sys.exc_info()
+                elif explicit_ei == "exception":
+                    ei = e
+                else:
+                    raise ValueError()
         else:
             ei = True
 
@@ -339,6 +391,9 @@ class TestConsoleRenderer:
                 rv = cr(None, None, ed)
                 ei = sys.exc_info()
 
+        if isinstance(ei, BaseException):
+            ei = (ei.__class__, ei, ei.__traceback__)
+
         exc = dev._format_exception(ei)
 
         assert (
@@ -400,7 +455,7 @@ class TestConsoleRenderer:
         If force_colors is True, use colors even if the destination is non-tty.
         """
         cr = dev.ConsoleRenderer(
-            colors=dev._use_colors, force_colors=dev._use_colors
+            colors=dev._has_colors, force_colors=dev._has_colors
         )
 
         rv = cr(
@@ -424,7 +479,7 @@ class TestConsoleRenderer:
             + styles.reset
         ) == rv
 
-        assert not dev._use_colors or dev._ColorfulStyles is cr._styles
+        assert not dev._has_colors or dev._ColorfulStyles is cr._styles
 
     @pytest.mark.parametrize("rns", [True, False])
     def test_repr_native_str(self, rns):
